pub fn redis_bf_exists(key: &str, item: &str) -> KnowledgeResult<bool>Expand description
Check whether an item exists in a Bloom filter.
Returns true if the item may exist, false if it definitely does not.
Requires the RedisBloom module.
pub fn redis_bf_exists(key: &str, item: &str) -> KnowledgeResult<bool>Check whether an item exists in a Bloom filter.
Returns true if the item may exist, false if it definitely does not.
Requires the RedisBloom module.