MEM_SQLITE_INS

Struct MEM_SQLITE_INS 

pub struct MEM_SQLITE_INS { /* private fields */ }

Methods from Deref<Target = Pool<SqliteConnectionManager>>

pub fn get(&self) -> Result<PooledConnection<M>, Error>

Retrieves a connection from the pool.

Waits for at most the configured connection timeout before returning an error.

pub fn get_timeout( &self, timeout: Duration, ) -> Result<PooledConnection<M>, Error>

Retrieves a connection from the pool, waiting for at most timeout

The given timeout will be used instead of the configured connection timeout.

pub fn try_get(&self) -> Option<PooledConnection<M>>

Attempts to retrieve a connection from the pool if there is one available.

Returns None if there are no idle connections available in the pool. This method will not block waiting to establish a new connection.

pub fn state(&self) -> State

Returns information about the current state of the pool.

pub fn max_size(&self) -> u32

Returns the configured maximum pool size.

pub fn min_idle(&self) -> Option<u32>

Returns the configured mimimum idle connection count.

pub fn test_on_check_out(&self) -> bool

Returns if the pool is configured to test connections on check out.

pub fn max_lifetime(&self) -> Option<Duration>

Returns the configured maximum connection lifetime.

pub fn idle_timeout(&self) -> Option<Duration>

Returns the configured idle connection timeout.

pub fn connection_timeout(&self) -> Duration

Returns the configured connection timeout.